This crate implements a tree data structure.
A tree is a directed acyclic graph of nodes, all of them carrying an optional payload, as well as an optional annotation to the edge linking them to their parent.
Internally, nodes are stored in a vec, and the topology of the tree
Each node in the tree may contain an arbitratry number of children.
Modules
Structs
- Node
- A node in the tree. A
Nodecan carry aPayload, and can annotate the branch to its parent with anEdge. - Node
Handle - Tree